

clear
set more off
version 16
set seed 12345

capture do c:\ado\profile_temp.do
capture cd "$GoogleDriveLaptop"
capture cd "$GoogleDriveWork"
capture cd ".\Talks\2019\SER\01_Multilevel\examples\"

global GraphWidth16x9 = 1920*2
global GraphHeight16x9 = 1080*2

set linesize 120
capture log close
log using test, replace

timer clear
timer on 1


use test.dta, clear

describe

list teacher student age cage sex score experience  ///
     if inrange(student,68,69),          ///
     noobs sepby(student) ab(10)

summarize teacher student age cage sex score experience

twoway (line score age if teacher ==3 & inrange(student,60,69), connect(ascending)), ///
	title("Test Score by Age for students 60-69", size(medsmall))	///
	ytitle("Test Score ")	///
	xtitle("Age (years)")
graph export ./graphs/longitudinal1.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

twoway (line score cage if teacher ==3 & inrange(student,60,69), connect(ascending)), ///
	title("Test Score by Centered Age for students 60-69", size(medsmall))	///
	ytitle("Test Score")	///
	xtitle("Age (years)")
graph export ./graphs/longitudinal1b.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace


// GRAND MEAN ONLY
// =============================================================================	
mixed score, stddev

// CREATE A VARIABLE FOR THE FIXED EFFECT (GrandMean)
predict GrandMean, xb
label var GrandMean "GrandMean"

#delimit ;
twoway  (line GrandMean age, lcolor(black) lwidth(thick))              		
        (scatter score age, mcolor(red) msize(tiny)),                  		
        ytitle("Test Score ", margin(medsmall))              	
        legend(cols(4) size(small))                                     	
        title("Test Score by Age", size(medium))
;
#delimit cr

graph export ./graphs/longitudinal2.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

drop GrandMean

summ score



// RANDOM INTERCEPTS (VARIANCE COMPONENTS) MODEL
// =============================================================================
mixed score, || teacher: || student:, stddev

// CREATE A VARIABLE FOR THE FIXED EFFECT (GrandMean)
predict GrandMean, xb
label var GrandMean "GrandMean"

// CREATE VARIABLES FOR THE RANDOM EFFECTS
predict teacherEffect, reffects relevel(teacher)
predict studentEffect, reffects relevel(student)

// CREATE VARIABLES FOR teacherMean and studentMean
generate teacherMean = GrandMean + teacherEffect
generate studentMean = GrandMean + teacherEffect + studentEffect

// CREATE VARIABLE FOR THE OBSERVATION LEVEL RESIDUAL
predict residual, residuals

#delimit ;
twoway  (line GrandMean age, lcolor(black) lwidth(thick))      			
        (line teacherMean age, lcolor(blue) lwidth(medthick))   		
        (line studentMean age, lcolor(green) connect(ascending)) 		
        (scatter score age, mcolor(red) msize(medsmall))         		
        if teacher ==3 & student==69,                               	
        ytitle("Test Score", margin(medsmall))      		
        legend(cols(4) size(vsmall))                             		
        title("Multilevel Model of Test Score Over Age", size(medium))
		subtitle("Teacher 3, Student 69")
;
#delimit cr

graph export ./graphs/longitudinal3.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

format %9.2f GrandMean teacherEffect studentEffect residual
list student age score GrandMean teacherEffect studentEffect residual  ///
     if student==69, noobs  abbreviate(16) 

display  68.71 + 0.70 + 3.78 + 9.82


drop GrandMean teacherEffect studentEffect teacherMean studentMean residual





// RANDOM INTERCEPTS (VARIANCE COMPONENTS) MODEL WITH FIXED SLOPE FOR AGE
// =============================================================================
mixed score cage, || teacher: || student: , cov(indep) stddev

// CREATE A VARIABLE FOR THE FIXED EFFECT (GrandMean)
predict GrandMean, xb
label var GrandMean "GrandMean"

// CREATE VARIABLES FOR THE RANDOM EFFECTS
predict teacherEffect, reffects relevel(teacher)
predict studentEffect_cons, reffects relevel(student)

// CREATE VARIABLES FOR teacherMean and studentMean_cons
generate teacherMean = GrandMean + teacherEffect
generate studentMean_cons = GrandMean + teacherEffect + studentEffect_cons

#delimit ;
twoway  (line GrandMean age, lcolor(black) lwidth(thick))             	
        (line teacherMean age, lcolor(blue) lwidth(medthick))          	
        (line studentMean_cons age, lcolor(green) connect(ascending))   	
        (scatter score age, mcolor(red) msize(medsmall))              
        if teacher ==3 & student==69,                                                 
        ytitle("Test Score ", margin(medsmall))              
        legend(cols(3) size(small))                                     
        title("Multilevel Model of Test Score Over Age", size(medium))
		subtitle("Teacher 3, Student 69")
;
#delimit cr

graph export ./graphs/longitudinal4.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

drop GrandMean teacherEffect studentEffect_cons teacherMean studentMean_cons




// RANDOM INTERCEPTS (VARIANCE COMPONENTS) MODEL WITH RANDOM SLOPE FOR AGE
// =============================================================================
mixed score cage, || teacher: || student: cage, cov(indep) stddev

margins, at(cage=(-2(1)2))

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Test Score") 
	ylabel(, angle(horizontal)) 
	xtitle("Centered Age (years)") 
	title("Predicted Test Score Over Age")
	legend(position(12) ring(0))
;
#delimit cr
graph export ./graphs/longitudinal4b.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

predict GrandMean, xb
label var GrandMean "GrandMean"

// CREATE VARIABLES FOR THE RANDOM EFFECTS
predict teacherEffect, reffects relevel(teacher)
predict studentEffect_year studentEffect_cons, reffects relevel(student)

// CREATE VARIABLES FOR teacherMean, studentMean_cons, and studentMean_year
generate teacherMean = GrandMean + teacherEffect
generate studentMean_cons = GrandMean + teacherEffect + studentEffect_cons
generate studentMean_year = GrandMean + teacherEffect + studentEffect_cons + ///
                     (cage*studentEffect_year)

#delimit ;
twoway  (line GrandMean age, lcolor(black) lwidth(thick))             	
        (line teacherMean age, lcolor(blue) lwidth(medthick))          	
        (line studentMean_cons age, lcolor(green) connect(ascending))   	
        (line studentMean_year age, lcolor(brown) connect(ascending))   	
        (scatter score age, mcolor(red) msize(medsmall))              
        if teacher ==3 & student==69,                                                 
        ytitle("Test Score", margin(medsmall))              
        legend(cols(3) size(small))                                     
        title("Multilevel Model of Test Score Over Age", size(medium))
		subtitle("Teacher 3, Student 69")
;
#delimit cr

graph export ./graphs/longitudinal5.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

drop GrandMean teacherEffect studentEffect_year studentEffect_cons teacherMean studentMean_cons studentMean_year



// CLUSTER ROBUST MODEL
// =============================================================================
mixed score, || teacher: || student:, stddev


// CALCULATE THE PROPORTION OF VARIANCE EXPLAINED AT EACH LEVEL
mixed score cage || teacher: || student: cage , nolog noheader
estat icc

display "Proportion of variance at the teacher level = " 0.70 / (0.70 + 28.85 + 4.42)
display "Proportion of variance at the student level = " 28.85 / (0.70 + 28.85 + 4.42)





// FIXED VS RANDOM EFFECTS
// =============================================================================

// TEACHER	 TREATED AS RANDOM
mixed score cage || teacher: || student: cage , stddev nolog noheader

// FIXED EFFECTS MODEL: NO INTERCEPT
mixed score cage ibn.teacher, nocons || student: cage , stddev nolog noheader

margins teacher, at(cage=(-2(1)2))

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Test Score") 
	ylabel(, angle(horizontal)) 
	xtitle("Centered Age (years)") 
	title("Predicted Test Score Over Age")
	legend(ring(0) cols(1) position(11))
;
#delimit cr
graph export ./graphs/longitudinal4c.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace




// FIXED EFFECTS MODEL: WITH INTERCEPT
mixed score cage i.teacher || student: cage , stddev nolog noheader





// BINARY OUTCOME teacher TREATED AS RANDOM
// =========================================================================
clear
use test.dta, clear
melogit pass cage || teacher: || student: cage, or nolog cov(indep)
margins, at(cage=(-2(1)2))

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Probability of Passing") 
	ylabel(0(0.2)1, angle(horizontal)) 
	xtitle("Age (years)")
    xlabel(-2 "14" -1 "15" 0 "16" 1 "17" 2 "18")
	title("Predicted Probability of Passing By Age")
	subtitle("Teacher Treated As Random Effect")
	legend(position(12) ring(0))
;
#delimit cr
graph export ./graphs/melogit1.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace



// BINARY OUTCOME teacher TREATED AS FIXED
// =========================================================================
melogit pass cage ibn.teacher, nocons || student: cage, or cov(indep) nolog noheader
margins teacher, at(cage=(-2(1)2)) vsquish

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Probability of Passing") 
	ylabel(0(0.2)1, angle(horizontal)) 
	xtitle("Age (years)")
    xlabel(-2 "14" -1 "15" 0 "16" 1 "17" 2 "18")
	title("Predicted Probability of Passing By Age")
	subtitle("Teacher Treated As Fixed Effect")
	legend(ring(0) cols(1) position(11))
;
#delimit cr
graph export ./graphs/melogit2.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace

 

 
// CROSSED RANDOM EFFECTS 
clear
use test.dta
list teacher student sex age cage if student==1

clear
use test_crossed.dta
list teacher student sex age cage if student==1

tab teacher age if student==1

describe

summarize




// Fit the model using maximum likelihood
// =============================================================================
mixed score cage i.sex || _all: R.teacher || student: cage, nolog noheader stddev
mixed, noheader stddev
margins sex, at(cage=(-2(1)2))

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Test Score") 
	ylabel(60(5)80, angle(horizontal)) 
	xtitle("Age (years)") 
    xlabel(-2 "14" -1 "15" 0 "16" 1 "17" 2 "18")
	title("Predicted Test Score By Age")
	legend(ring(0) cols(1) position(11))
;
#delimit cr
graph export ./graphs/crossed.png, as(png) width($GraphWidth16x9) height($GraphHeight16x9) replace


 
 
// BAYESIAN MULTILEVEL MODELS
// =============================================================================
set seed 16
bayes: mixed score cage i.sex || _all: R.teacher || student: cage
bayesstats summary _all
 


timer off 1
timer list


log close

translate "test.smcl" "test.log", replace linesize(120) translator(smcl2log)

