



clear
set more off
set seed 123
version 16

capture do c:\ado\profile_temp.do
capture cd "$GoogleDriveLaptop"
capture cd "$GoogleDriveWork"

global GraphWidth16x9 = 1920*2
global GraphHeight16x9 = 1080*2


clear
set obs 20
gen id = _n + (20*`i' - 20)


// CREATE THE MULTILEVEL DATA FOR THE EXAMPLES
// =============================================================================
clear


// LEVEL 3 (TEACHER)
// =============================
set obs 3
gen teacher = _n

// LEVEL 3 RESIDUAL
generate u_i = rnormal(0,1)


// LEVEL 2 (STUDENT)
// =============================
expand 25
gen student = _n

// CREATE SEX COVARIATE
gen RandNum = runiform()
gen sex = RandNum<0.5
label define sex 0 "Female" 1 " Male"
label values sex sex
label var sex "Sex"
drop RandNum

// LEVEL 2 RESIDUALS
generate u_0ij = rnormal(0,5)
generate u_1ij = rnormal(0,2)

 
// LEVEL 1 (REPEATED MEASURES)
// =============================
expand 5
bysort student: gen age = _n + 13
bysort student: gen cage = age - 16


// LEVEL 1 RESIDUAL
generate e_ijk = rnormal(0,2)

// CREATE LONGITUDINAL TEST DATA
generate score = 70 + 2.3*cage + u_i + u_0ij + cage*u_1ij + e_ijk
replace score = floor(score)


// CREATE "PASS" VARIABLE
gen pass = (score>70)
label var pass "Passing score (score>=70)"

label var teacher "Teacher ID"
label var student "Student ID"
label var age "Age (years)"
label var cage "Centered Age"
label var sex "Student Sex"
label var score "Test Score (0-100)"

gen zero = 0
label var zero "Column of zeros for graphs"

// ADD A VARIABLE FOR TEACHER EXPERIENCE (THOUGH IT HAS NO EFFECT ON score)
set seed 12345
gen experience = .
forvalues i = 1/3 {
	local randnum = runiformint(3,10)
	replace experience = `randnum'  if teacher==`i'
}
label var experience "Teacher experience (years)"


drop u_i u_0ij u_1ij e_ijk
order teacher student age cage sex score pass experience zero
gsort +teacher +student +age
save test.dta, replace





twoway (line score cage, connect(ascending)), title("Weight by Age for Families 97-100", size(medsmall))


twoway (line score cage if student==4, connect(ascending)), title("Weight by Age for Families 97-100", size(medsmall))


 mixed score cage, || teacher: || student: cage , cov(indep) stddev
 
 
 

 
// IDENTIFY AN OBSERVATION FOR GRAPH
mixed score cage, || teacher: || student: cage, cov(indep)

predict GrandMean, xb
label var GrandMean "GrandMean"

// CREATE VARIABLES FOR THE RANDOM EFFECTS
predict teacherEffect, reffects relevel(teacher)
predict studentEffect_year studentEffect_cons, reffects relevel(student)

// CREATE VARIABLES FOR teacherMean, studentMean_cons, and studentMean_year
generate teacherMean = GrandMean + teacherEffect
generate studentMean_cons = GrandMean + teacherEffect + studentEffect_cons
generate studentMean_year = GrandMean + teacherEffect + studentEffect_cons + ///
                     (cage*studentEffect_year)
					 
summ teacherEffect

list teacher student teacherEffect studentEffect_year studentEffect_cons     ///
     if teacherEffect==r(max) & studentEffect_cons>0 & studentEffect_year>0

	 
	 
#delimit ;
twoway  (line GrandMean age, lcolor(black) lwidth(thick))             	
        (line teacherMean age, lcolor(blue) lwidth(medthick))          	
        (line studentMean_cons age, lcolor(green) connect(ascending))   	
        (line studentMean_year age, lcolor(brown) connect(ascending))   	
        (scatter score age, mcolor(red) msize(medsmall))              
        if teacher ==3 & student==69,                                                 
        ytitle("Test Score", margin(medsmall))              
        legend(cols(3) size(small))                                     
        title("Multilevel Model of Test Score Over Age", size(medium))
		subtitle("Teacher 1, Student 14")
;
#delimit cr










// Create a dataset with crossed random effects with random slope
// =============================================================================
set seed 123456789
clear
set obs 200
generate student = _n
generate sex = rbinomial(1,0.5)
generate u_0i = rnormal(0,10)
generate u_1i = rnormal(0,1)
expand 5
bysort student: generate age = _n + 13
generate cage = age - 16


// Create the teacher random effects
generate teacher = runiformint(1,8)
generate u_2i = .
forvalues i = 1/8 {
	local re = rnormal(0,3)
	replace u_2i = `re' if teacher==`i'
}

generate e_ij = rnormal(0,5)

generate score = 70 + 0.5*cage + 2.1*sex + u_0i + u_1i*cage + u_2i + e_ij
replace score = floor(score)

label var cage "Age - 16"
label var student "Student Identification Number"
label var sex "Student Sex"
label define sex 0 "Male" 1 "Female"
label values sex sex
label var age "Age (years)"
label var teacher "Teacher Identification Number"
label var score "Math Test Score"

drop u_0i u_1i u_2i e_ij
order teacher student sex age cage  score

gsort +student +age
save test_crossed.dta, replace



mixed score cage i.sex || _all: R.teacher || student: cage, nolog noheader stddev
mixed, noheader stddev
margins sex, at(cage=(-2(1)2))

#delimit ;
marginsplot, 
	ytitle("Marginal Predicted Test Score") 
	ylabel(60(5)80, angle(horizontal)) 
	xtitle("Age (years)") 
    xlabel(-2 "14" -1 "15" 0 "16" 1 "17" 2 "18")
	title("Predicted Test Score By Age")
	legend(ring(0) cols(1) position(11))
;
#delimit cr





  
 
 
 



